#Project Description

A simple binder for the GTA5 game

##Functions

1)When you click on the binds, it sends the messages we need to the chat

2)Simplifies writing chat commands in GTA Online

3)Reassign the keys for yourself by changing lines 26 and 27 in the binds.py file

4)You can change the same lines so that other messages are sent